__import__("candyland.actors.compile", globals(), locals())
__import__("candyland.actors.manage", globals(), locals())
__import__("candyland.actors.parse", globals(), locals())
__import__("candyland.actors.storj", globals(), locals())
__import__("candyland.actors.transact", globals(), locals())



"""
    Appellation: clock
    Contributors: FL03 <jo3mccain@icloud.com> (https://gitlab.com/FL03)
    Description:
        ... Summary ...
"""
from datetime import datetime


def timestamp() -> str:
    return str(datetime.now())



"""
    Appellation: message
    Contributors: FL03 <jo3mccain@icloud.com> (https://gitlab.com/FL03)
    Description:
        ... Summary ...
"""
from candyland.core.utils import clock
from pydantic import BaseModel


class Message(BaseModel):
    message: str
    timestamp: str = clock.timestamp()



"""
    Appellation: fs
    Contributors: FL03 <jo3mccain@icloud.com> (https://gitlab.com/FL03)
    Description:
        ... Summary ...
"""
import os
from pydantic import BaseModel


def try_extend_path(root: str = os.path.expanduser("~"), path: str = None) -> str:
    try:
        return os.path.join(root, path)
    except TypeError:
        return root


class IndexedFolder(BaseModel):
    root: str
    dirs: list
    files: list


class Filer(object):
    source: str
    target: str = None

    def __init__(self, source: str = os.path.expanduser("~")):
        self.source = source

    def set_target(self, target: str):
        self.target = target
        return self

    def walk(self, target: str = None):
        if target:
            self.set_target(target)
        return [
            IndexedFolder(root=r, dirs=ds, files=fs)
            for r, ds, fs in os.walk(try_extend_path(self.source, self.target))
        ]



"""
    Appellation: __main__
    Contributors: FL03 <jo3mccain@icloud.com> (https://gitlab.com/FL03)
    Description:
        ... Summary ...
"""
from pydantic import BaseModel, BaseSettings
from typing import List, Optional


class AppSettings(BaseModel):
    authors: Optional[List[str]]
    mode: str = "development"
    name: str
    token: str

    def slug(self) -> str:
        return self.name.lower()


class Settings(BaseSettings):
    application: AppSettings


class Application(object):
    def __init__(self, *args, **kwargs):
        self.args = args
        self.kwargs = kwargs


class CommandLineInterface(Application):
    def run(self):
        pass


if __name__ == "__main__":
    from candyland.components.messages import Message

    print(Message(message="Welcome to candyland!"))



"""
    Appellation: pipeline
    Contributors: FL03 <jo3mccain@icloud.com> (https://gitlab.com/FL03)
    Description:
        ... Summary ...
"""
import subprocess


class Sleeve(object):
    application: str
    result: subprocess.CompletedProcess
    output: list

    def execute(self, *args):
        self.result = subprocess.run([self.application, *args], capture_output=True)
        return self

    def help(self, *args):
        self.execute("--help", *args)
        return self

    def lines(self):
        self.output = str(self.result.stdout).strip("b'").split("\\n")
        return self

    def __repr__(self): return "\n".join(self.lines().output)


class Storj(Sleeve):
    def __init__(self):
        self.application = 'uplink'

    def access(self, *args):
        self.execute("access", *args)
        return self

    def cp(self, *args):
        self.execute("cp", *args)
        return self

    def ls(self, *args):
        self.execute("ls", *args)
        return self

    def mb(self, *args):
        self.execute("mb", *args)
        return self

    def meta(self, *args):
        self.execute("meta", *args)
        return self

    def mv(self, *args):
        self.execute("mv", *args)
        return self

    def rb(self, *args):
        self.execute("rb", *args)
        return self

    def rm(self, *args):
        self.execute("rm", *args)
        return self

    def setup(self, *args):
        self.execute("setup", *args)
        return self

    def share(self, *args):
        self.execute("share", *args)
        return self

    def version(self):
        self.execute("version")
        return self


if __name__ == '__main__':
    print(Storj().help("meta"))



"""
    Appellation: structs
    Contributors: FL03 <jo3mccain@icloud.com> (https://gitlab.com/FL03)
    Description:
        ... Summary ...
"""


def list_from(a, *args): return [a, *args]


def merge_lists(a: list, b: list) -> list: return [*a, *b]



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['candyland',
 'candyland.actors',
 'candyland.actors.compile',
 'candyland.actors.manage',
 'candyland.actors.parse',
 'candyland.actors.storj',
 'candyland.actors.transact',
 'candyland.components',
 'candyland.components.messages',
 'candyland.components.pipelines',
 'candyland.core',
 'candyland.core.utils',
 'candyland.data',
 'candyland.data.models',
 'candyland.data.proofs',
 'candyland.data.schemas']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.10.2,<2.0.0']

setup_kwargs = {
    'name': 'candyland',
    'version': '0.1.4',
    'description': '',
    'long_description': '',
    'author': 'FL03',
    'author_email': 'jo3mccain@icloud.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<3.11',
}


setup(**setup_kwargs)



__name__ = "candyland"
__package__ = "candyland"
__version__ = "0.1.4"

__import__("candyland.actors", globals(), locals())
__import__("candyland.components", globals(), locals())
__import__("candyland.core", globals(), locals())
__import__("candyland.data", globals(), locals())
